## {{project_name}}


### What?


### Why?


### Installation

#### Plug & Play:
```bash
# Install via pipx
pipx install {{project_name}}

# Install via pip
pip install {{project_name}}
```

#### Install for development:

Clone the repository:
```bash
git clone https://github.com/{{username}}/{{project_name}}.git
cd {{project_name}}
```

Install the dependencies and the package:
```bash
make install

# or manually:

python -m venv venv
source venv/bin/activate
pip install -r requirements.txt
```

#### System Requirements

Before using {{project_name}}, ensure you have the following installed:

- Python >= `3.10`


### Usage


### Features


### Acknowledgments


### Contributing

Contributions are welcome!

If you have a feature request, bug report, or a pull request, please open an issue or submit a PR.


### License

{{project_name}} is released under ...

